from logging import getLogger

from django import forms
from django.forms.models import InlineForeignKeyField

from chance.models import (Registration, Event, EventChoiceSelection, Talk, 
                            Transaction)



log = getLogger('chance.forms')

class RegistrationForm(forms.ModelForm):

    class Meta:
        model = Registration
        fields = ('event', 'attendee_name', 'attendee_email',
                'fee_option')

    def __init__(self, *args, **kwargs):
        self.event_object = kwargs.pop('event')
        assert isinstance(self.event_object, Event)

        super(RegistrationForm, self).__init__(*args, **kwargs)

        self.add_event_fields()
        self.fields['event'] = InlineForeignKeyField(self.event_object)
        self.fields['fee_option'].queryset = self.event_object.fee_options.filter(available=True)

        if self.event_object.fee_options.count() > 0:
            self.fields['fee_option'].empty_label = None
            self.fields['fee_option'].required = True
        else:
            del self.fields['fee_option']


    def add_event_fields(self):
        for choice in self.event_object.choices.all():
            if choice.allow_multiple:
                field = forms.ModelMultipleChoiceField
                widget = forms.CheckboxSelectMultiple
            else:
                field = forms.ModelChoiceField
                widget = forms.Select

            self.fields[choice.name] = field(label=choice.label,
                    help_text=choice.description, required=choice.required,
                    queryset=choice.options.filter(enabled=True), widget=widget)
            if self.instance:
                if not choice.name in self.initial:
                    selections = self.instance.selections.filter(option__choice=choice)

                    if choice.allow_multiple:
                        self.initial[choice.name] = [s.option for s in selections]
                    elif selections.count() == 1:
                        self.initial[choice.name] = selections.get().option

    def save(self, **kwargs):
        result = super(RegistrationForm, self).save()
        self.save_related()
        return result

    def save_related(self):
        selections = self.instance.selections

        for field in self.event_object.choices.all():
            if field.allow_multiple:
                field_selections = selections.filter(option__choice=field)
                current = set(s.option for s in field_selections)
                new = set(self.cleaned_data[field.name])
                field_selections.filter(option__in=list(current -
                    new)).delete()

                for add in new - current:
                    EventChoiceSelection.objects.create(registration=self.instance,
                            option=add)
            else:
                if self.cleaned_data[field.name]:
                    current, created = self.instance.selections.get_or_create(
                        option__choice=field,
                        defaults={'option': self.cleaned_data[field.name]})
                    if current.option != self.cleaned_data[field.name]:
                        current.option = self.cleaned_data[field.name]
                else:
                    self.instance.selections.filter(option__choice=field).delete()

class TalkSubmissionForm(forms.ModelForm):
    class Meta:
        model = Talk
        fields = ('event', 'title', 'presenter', 'description')

    def __init__(self, *args, **kwargs):
        self.event_object = kwargs.pop('event', None)
        if self.event_object is not None:
            assert isinstance(self.event_object, Event)

        super(TalkSubmissionForm, self).__init__(*args, **kwargs)
        if self.event_object is not None:
            self.fields['event'] = InlineForeignKeyField(self.event_object)

class TransactionConfirmForm(forms.ModelForm):
    class Meta:
        model = Transaction
        fields = ('registrations',)

    def __init__(self, *args, **kwargs):
        self.registration_qs = kwargs.pop('registrations',
                Registration.objects.none())
        super(TransactionConfirmForm, self).__init__(*args, **kwargs)

        self.fields['registrations'] = forms.ModelMultipleChoiceField(
            label='Registrations', required=True,
            queryset=self.registration_qs, widget=forms.CheckboxSelectMultiple)
        self.initial['registrations'] = self.registration_qs.all()




from logging import getLogger

from django.conf import settings
from django.core.mail import send_mail, mail_managers
from django.db.models.signals import post_save
from django.template import Context
from django.template.loader import get_template, select_template

from chance.models import Registration, Transaction



log = getLogger('chance.signals')

def notify_attendee_of_registration(sender, instance, created, raw, **kwargs):
    if raw or not created:
        return
    context = Context({'object': instance})
    subject =  get_template('chance/registration_email_subject.txt').render(context)
    subject = ''.join(subject.splitlines())
    message = get_template('chance/registration_email.txt').render(context)

    send_mail(subject, message, getattr(settings, 'CHANCE_FROM_EMAIL',
        settings.SERVER_EMAIL), [instance.attendee_email])


def notify_managers_of_registration(sender, instance, created, raw, **kwargs):
    if raw or not created:
        return
    context = Context({'object': instance})
    subject = select_template([
        'chance/registration_email_manager_subject.txt',
        'chance/registration_email_subject.txt']).render(context)
    subject = ''.join(subject.splitlines())

    message = select_template([
        'chance/registration_email_manager.txt',
        'chance/registration_email.txt']).render(context)

    mail_managers(subject, message, getattr(settings, 'CHANCE_FROM_EMAIL',
        settings.SERVER_EMAIL))

def mark_transaction_registrations(sender, instance, created, raw, **kwargs):
    if raw:
        return

    if not instance.paid_in_full:
        log.error('Transaction not paid in full')
        log.error('%s paid of %s' % (repr(instance.amount_paid),
            repr(instance.total),))
        return

    for registration in instance.registrations.all():
        registration.paid = True
        registration.save()

if getattr(settings, 'CHANCE_NOTIFY_ATTENDEE_ON_REGISTRATION', True):
    post_save.connect(notify_attendee_of_registration, sender=Registration)

if getattr(settings, 'CHANCE_NOTIFY_MANAGERS_ON_REGISTRATION', True):
    post_save.connect(notify_managers_of_registration, sender=Registration)

if getattr(settings, 'CHANCE_UPDATE_REGISTRATION_ON_TRANSACTION', True):
    post_save.connect(mark_transaction_registrations, sender=Transaction)




from decimal import Decimal
from logging import getLogger
from urllib2 import urlopen

from django.contrib import messages
from django.contrib.auth.decorators import login_required, permission_required
from django.conf import settings
from django.db.models import permalink
from django.http import (HttpResponseForbidden, HttpResponseRedirect, 
                         HttpResponse, Http404, HttpResponseBadRequest)
from django.shortcuts import get_object_or_404
from django.utils.decorators import method_decorator
from django.utils.simplejson import load
from django.views import generic

from chance.forms import (RegistrationForm, TalkSubmissionForm,
                            TransactionConfirmForm)
from chance.models import Event, Registration, Talk, Transaction



log = getLogger('chance.views')

class EventMixin(object):
    def get(self, request, *args, **kwargs):
        self.event = get_object_or_404(Event, pk=kwargs.get('event', None))
        del kwargs['event']
        return super(EventMixin, self).get(request, *args, **kwargs)

    def post(self, request, *args, **kwargs):
        self.event = get_object_or_404(Event, pk=kwargs.get('event', None))
        del kwargs['event']
        return super(EventMixin, self).post(request, *args, **kwargs)

    def get_context_data(self, **kwargs):
        kwargs = super(EventMixin, self).get_context_data(**kwargs)
        kwargs['event'] = self.event
        return kwargs


class EventRelatedFormMixin(EventMixin):
    def get_form_kwargs(self):
        kwargs = super(EventRelatedFormMixin, self).get_form_kwargs()
        kwargs['event'] = self.event
        return kwargs

class RegistrationFormMixin(EventRelatedFormMixin):
    form_class = RegistrationForm
    model = Registration

    def form_valid(self, form):
        result = super(RegistrationFormMixin, self).form_valid(form)
        if self.request.user.is_authenticated():
            self.object.owner = self.request.user
            self.object.save()
        messages.info(self.request, 'Registration for %s saved' %
                (form.cleaned_data['attendee_name'],))
        return result

class CreateRegistrationView(RegistrationFormMixin, generic.CreateView):
    def get(self, request, *args, **kwargs):
        self.event = get_object_or_404(Event, pk=kwargs.get('event', None))
        if not self.event.registration_open:
            messages.error(request, u'%s registration is no longer available' %
                    (self.event.name,))
            return HttpResponseRedirect(self.event.get_absolute_url())
        return super(CreateRegistrationView, self).get(request, *args,
                **kwargs)

    def post(self, request, *args, **kwargs):
        self.event = get_object_or_404(Event, pk=kwargs.get('event', None))
        if not self.event.registration_open:
            messages.error(request, u'%s registration is no longer available' %
                    (self.event.name,))
            return HttpResponseRedirect(self.event.get_absolute_url())
        return super(CreateRegistrationView, self).post(request, *args,
                **kwargs)

class UpdateRegistrationView(RegistrationFormMixin, generic.UpdateView):
    pass

class DeleteRegistrationView(RegistrationFormMixin, generic.DeleteView):
    def can_delete(self):
        return not self.object.paid

    def get(self, request, *args, **kwargs):
        self.request = request
        self.args = args
        self.kwargs = kwargs
        self.object = self.get_object()
        if not self.can_delete():
            messages.error(request, u'This registration cannot be canceled')
            return HttpResponseRedirect(self.object.get_absolute_url())
        return super(DeleteRegistrationView, self).get(request, *args, **kwargs)

    def post(self, request, *args, **kwargs):
        self.request = request
        self.args = args
        self.kwargs = kwargs
        self.object = self.get_object()
        if not self.can_delete():
            messages.error(request, u'This registration cannot be canceled')
            return HttpResponseRedirect(self.object.get_absolute_url())
        return super(DeleteRegistrationView, self).post(request, *args, **kwargs)


    @permalink
    def get_success_url(self):
        return ('chance:chance_event', (), {'pk': self.object.event.pk},)

class RegistrationDetailView(EventMixin, generic.DetailView):
    model = Registration

    @method_decorator(login_required())
    def get(self, request, *args, **kwargs):
        self.object = self.get_object()
        if not self.request.user.has_perm('chance.change_registration') \
            and not self.request.user == self.object.owner:
            return HttpResponseForbidden()
        return super(RegistrationDetailView, self).get(request, *args,
                **kwargs)

class RegistrationListView(EventMixin, generic.ListView):
    model = Registration

    def get_queryset(self):
        qs = Registration.objects.filter(event=self.event)

        if self.request.user.has_perm('chance.change_registration'):
            return qs
        if self.request.user.is_authenticated():
            return qs.filter(owner=self.request.user)
        return qs.none()

class TalkListView(EventMixin, generic.ListView):
    model = Talk

class TalkDetailView(EventMixin, generic.DetailView):
    model = Talk

class TalkSubmissionCreateView(EventRelatedFormMixin, generic.CreateView):
    model = Talk
    form_class = TalkSubmissionForm

    def form_valid(self, form):
        result = super(TalkSubmissionCreateView, self).form_valid(form)
        if self.request.user.is_authenticated():
            self.object.owner = self.request.user
            self.object.save()
        messages.info(self.request, 'Talk submitted.')
        return result

class TalkSubmissionUpdateView(EventRelatedFormMixin, generic.UpdateView):
    model = Talk
    form_class = TalkSubmissionForm

    def get(self, request, *args, **kwargs):
        self.object = self.get_object()
        if not self.request.user.has_perm('change.change_talk') \
            and not self.request.user == self.object.owner:
                return HttpResponseForbidden()
        return super(TalkSubmissionUpdateView, self).get(request, *args,
                **kwargs)

    def post(self, request, *args, **kwargs):
        self.object = self.get_object()
        if not self.request.user.has_perm('change.change_talk') \
            and not self.request.user == self.object.owner:
                return HttpResponseForbidden()
        return super(TalkSubmissionUpdateView, self).post(request, *args,
                **kwargs)

        def form_valid(self, form):
            result = super(TalkSubmissionUpdateView, self).form_valid(form)
            messages.info(self.request, 'Talk updated.')
            return result

class TransactionConfirmView(generic.CreateView):
    models = Transaction
    form_class = TransactionConfirmForm
    template_name = 'chance/transaction_confirm.html'

    def get_registrations(self, request):
        return Registration.objects.filter(owner=request.user, paid=False)

    def get_form_kwargs(self):
        kwargs = super(TransactionConfirmView, self).get_form_kwargs()
        kwargs['registrations'] = self.registrations
        return kwargs

    def form_valid(self, form):
        response = super(TransactionConfirmView, self).form_valid(form)
        self.object.owner = self.request.user
        self.object.save()
        return response

    @method_decorator(login_required())
    def get(self, request, *args, **kwargs):
        registrations = self.get_registrations(request)
        if registrations.count() == 1:
            self.object = Transaction.objects.create(owner=request.user)
            self.object.registrations.add(registrations[0])
            return HttpResponseRedirect(self.get_success_url())
        if registrations.count() == 0:
            messages.error(request, 'No unpaid registrations found')
            return HttpResponseRedirect('/')
        self.registrations = registrations
        return super(TransactionConfirmView, self).get(request, *args,
                **kwargs)

    @method_decorator(login_required())
    def post(self, request, *args, **kwargs):
        self.registrations = self.get_registrations(request)
        return super(TransactionConfirmView, self).post(self, request, *args,
                **kwargs)

class TransactionView(generic.DetailView):
    model = Transaction

    @method_decorator(login_required)
    def get(self, request, *args, **kwargs):
        response = super(TransactionView, self).get(request, *args, **kwargs)

        if not (request.user.pk == self.object.owner.pk or
                request.user.has_perm('chance.change_transaction')):
            raise Http404()
        return response

    def get_context_data(self, **kwargs):
        context = super(TransactionView, self).get_context_data(**kwargs)
        context['total'] = self.object.total
        context['payment_url'] = settings.PAYMENT_POST_URL
        context['payment_params'] = getattr(settings, 'PAYMENT_PARAMS', {})
        context['payment_amount_field'] = settings.PAYMENT_AMOUNT_FIELD
        context['payment_transaction_id_field'] = \
            settings.PAYMENT_TRANSACTION_ID_FIELD
        return context

class TransactionCancel(generic.DeleteView):
    model = Transaction
    success_url = '/'

    @method_decorator(login_required)
    def get(self, request, *args, **kwargs):
        response = super(TransactionCancel, self).get(request, *args, **kwargs)

        if not (request.user.pk == self.object.owner.pk or 
                request.user.has_perm('chance.delete_transaction')):
            raise Http404()

        return response

    @method_decorator(login_required)
    def post(self, request, *args, **kwargs):
        self.request = request
        self.args = args
        self.kwargs = kwargs
        self.object = self.get_object()

        if not (request.user.pk == self.object.owner.pk or 
                request.user.has_perm('chance.delete_transaction')):
            raise Http404()

        return super(TransactionCancel, self).post(request, *args, **kwargs)

    def delete(self, request, *args, **kwargs):
        self.object = self.get_object()
        self.object.closed = True
        self.object.save()
        messages.success(request, u'Your transaction has been cancelled')
        return HttpResponseRedirect(self.get_success_url())

class TransactionNotifyView(generic.View):
    def get(self, request, *args, **kwargs):
        return HttpResponseForbidden()

    def post(self, request, *args, **kwargs):
        transaction = get_object_or_404(Transaction, pk=request.POST.get('transaction_id'))
        url = settings.PAYMENT_VERIFICATION_URL % transaction.__dict__
        try:
            connection = urlopen(url)
            data = load(connection)
            connection.close()
            assert unicode(transaction.id) == data.get('id',False)
            transaction.closed = data.get('success','0') != '0'
            transaction.amount_paid = Decimal(data.get('amount','0'))
            transaction.save()
        except:
            log.exception('Error getting transaction details')
            return HttpResponseBadRequest('Error getting transaction details')
        return HttpResponse('k thanks bye!')




from decimal import Decimal

from django.core.exceptions import ValidationError
from django.contrib.auth.models import User
from django.db import models



def validate_choice_name(value):
    if value and value.lower() in ('name', 'location', 'starts', 'ends',
        'registration_limit'):
        raise ValidationError(u'%s is a reserved field name, please choose ' \
                'a different one')

class Event(models.Model):
    name = models.CharField(max_length=255)
    location = models.CharField(max_length=255, null=True, blank=True)
    starts = models.DateTimeField()
    ends = models.DateTimeField()
    registration_limit = models.PositiveSmallIntegerField(null=True,
            blank=True, default=0)

    def __unicode__(self):
        return self.name

    @models.permalink
    def get_absolute_url(self):
        return ('chance:chance_event', (), {'pk': self.pk})

    @property
    def registration_open(self):
        return self.registration_limit == 0 or \
            self.registrations.count() < self.registration_limit

class EventFee(models.Model):
    event = models.ForeignKey(Event, related_name='fee_options')
    available = models.BooleanField(default=True)
    name = models.CharField(max_length=255)
    amount = models.DecimalField(max_digits=255,decimal_places=2)

    def __unicode__(self):
        return u'%s at %s' % (self.name, self.event.name,)

class EventChoice(models.Model):
    event = models.ForeignKey(Event, related_name='choices')
    order = models.PositiveIntegerField(default=0)
    name = models.CharField(max_length=32,
            validators=[validate_choice_name])
    label = models.CharField(max_length=255)
    description = models.TextField(null=True, blank=True)
    required = models.BooleanField(default=False)
    allow_multiple = models.BooleanField(default=False)

    class Meta:
        ordering = ('order',)
        unique_together = ('name', 'event',)


    def __unicode__(self):
        return '%s at %s' % (self.name, self.event.name,)

class EventChoiceOption(models.Model):
    choice = models.ForeignKey(EventChoice, related_name='options')
    order = models.PositiveIntegerField(default=0)
    display = models.CharField(max_length=128)
    enabled = models.BooleanField(default=True)

    class Meta:
        ordering = ('order',)

    def __unicode__(self):
        return self.display

class Registration(models.Model):
    event = models.ForeignKey(Event, related_name='registrations')
    owner = models.ForeignKey(User, related_name='+', null=True, blank=True)
    attendee_name = models.CharField(max_length=255)
    attendee_email = models.EmailField()
    created = models.DateTimeField(auto_now_add=True, editable=False,
            null=True, blank=True)
    fee_option = models.ForeignKey(EventFee, related_name='+', null=True,
            blank=True)
    paid = models.BooleanField(default=False)

    class Meta:
        ordering = ('created',)

    @models.permalink
    def get_absolute_url(self):
        return ('chance:chance_registration', (), {'pk': self.pk, 'event':
            self.event.pk})

    def __unicode__(self):
        return u'Registration for %s by %s' % (self.event.name,
                self.attendee_name,)

class EventChoiceSelection(models.Model):
    registration = models.ForeignKey(Registration, related_name='selections')
    option = models.ForeignKey(EventChoiceOption, related_name='+')


class Talk(models.Model):
    event = models.ForeignKey(Event, related_name='+')
    title = models.CharField(max_length=255, db_index=True)
    presenter = models.TextField(blank=True, null=True)
    description = models.TextField(blank=True, null=True)
    accepted = models.NullBooleanField(default=None)
    owner = models.ForeignKey(User, related_name='+', null=True, blank=True)

    def __unicode__(self):
        return self.title

    @models.permalink
    def get_absolute_url(self):
        return ('chance:talk', (), {'pk': self.pk, 'event': self.event.pk})

    class Meta:
        ordering = ('event', 'title',)


class Transaction(models.Model):
    owner = models.ForeignKey(User, related_name='+', null=True, blank=True)
    registrations = models.ManyToManyField(Registration, related_name='+')
    amount_paid = models.DecimalField(max_digits=8,decimal_places=2,
            default='0.00')
    created = models.DateTimeField(auto_now_add=True)
    closed = models.BooleanField(default=False)

    def __unicode__(self):
        return unicode(self.pk)

    @models.permalink
    def get_absolute_url(self):
        return ('chance:transaction', (), {'pk':self.pk})

    @property
    def total(self):
        return sum([r.fee_option.amount for r
            in self.registrations.all()])

    @property
    def paid_in_full(self):
        return self.total == self.amount_paid

try:
    import reversion

    reversion.register(EventChoiceOption)
    reversion.register(EventChoice, follow=['options'])
    reversion.register(EventFee)
    reversion.register(Event, follow=['fee_options', 'choices',
        'choices__options'])

    reversion.register(EventChoiceSelection)
    reversion.register(Registration, follow=['selections'])
    reversion.register(Talk)
    reversion.register(Transaction)
except ImportError:
    pass




from django.conf.urls.defaults import *
from django.contrib.auth.decorators import login_required
from django.views import generic
from django.views.decorators.csrf import csrf_exempt


from chance import views, models



urlpatterns = patterns('',
    url(r'^$', generic.ListView.as_view(model=models.Event), name='chance_event_list'),
    url(r'^(?P<pk>\d+)/$', generic.DetailView.as_view(model=models.Event),
        name='chance_event'),
    url(r'^(?P<event>\d+)/register/$', views.CreateRegistrationView.as_view(),
        name='chance_event_registration'),
    url(r'^(?P<event>\d+)/register/(?P<pk>\d+)/$', views.RegistrationDetailView.as_view(),
        name='chance_registration'),
    url(r'^(?P<event>\d+)/register/(?P<pk>\d+)/edit/$', views.UpdateRegistrationView.as_view(),
        name='chance_registration_update'),
    url(r'^(?P<event>\d+)/register/(?P<pk>\d+)/delete/$', views.DeleteRegistrationView.as_view(),
        name='chance_registration_delete'),
    url(r'^(?P<event>\d+)/registrations/$',
        views.RegistrationListView.as_view(),
        name='chance_registrations'),
    url(r'^(?P<event>\d+)/talks/$', views.TalkListView.as_view(),
        name='talks'),
    url(r'^(?P<event>\d+)/talks/(?P<pk>\d+)/$', views.TalkDetailView.as_view(),
        name='talk'),
    url(r'^(?P<event>\d+)/talks/add/$',
        login_required(views.TalkSubmissionCreateView.as_view()),
        name='submit_talk'),
    url(r'^(?P<event>\d+)/talks/(?P<pk>\d+)/update/$',
        login_required(views.TalkSubmissionUpdateView.as_view()),
        name='update_talk'),
    url(r'^transaction/confirm/$',
        views.TransactionConfirmView.as_view(),
        name='transaction_confirm'),
    url(r'^transaction/(?P<pk>\d+)/$',
        views.TransactionView.as_view(),
        name='transaction'),
    url(r'transaction/(?P<pk>\d+)/cancel/$',
        views.TransactionCancel.as_view(),
        name='transaction_cancel'),
    url(r'transaction/(?P<pk>\d+)/success/$',
        views.TransactionView.as_view(template_name='chance/transaction_success.html'),
        name='transaction_success'),
    url(r'^transaction/notify/$',
        csrf_exempt(views.TransactionNotifyView.as_view()),
        name='transaction_notify')
)



# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding field 'Registration.owner'
        db.add_column('chance_registration', 'owner',
                      self.gf('django.db.models.fields.related.ForeignKey')(blank=True, related_name='+', null=True, to=orm['auth.User']),
                      keep_default=False)


    def backwards(self, orm):
        # Deleting field 'Registration.owner'
        db.delete_column('chance_registration', 'owner_id')


    models = {
        'auth.group': {
            'Meta': {'object_name': 'Group'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '80'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'})
        },
        'auth.permission': {
            'Meta': {'ordering': "('content_type__app_label', 'content_type__model', 'codename')", 'unique_together': "(('content_type', 'codename'),)", 'object_name': 'Permission'},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        'auth.user': {
            'Meta': {'object_name': 'User'},
            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Group']", 'symmetrical': 'False', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'}),
            'username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'})
        },
        'chance.event': {
            'Meta': {'object_name': 'Event'},
            'ends': ('django.db.models.fields.DateTimeField', [], {}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'location': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'registration_limit': ('django.db.models.fields.PositiveSmallIntegerField', [], {'default': '0', 'null': 'True', 'blank': 'True'}),
            'starts': ('django.db.models.fields.DateTimeField', [], {})
        },
        'chance.eventchoice': {
            'Meta': {'ordering': "('order',)", 'unique_together': "(('name', 'event'),)", 'object_name': 'EventChoice'},
            'allow_multiple': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'event': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'choices'", 'to': "orm['chance.Event']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'label': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '32'}),
            'order': ('django.db.models.fields.PositiveIntegerField', [], {'default': '0'}),
            'required': ('django.db.models.fields.BooleanField', [], {'default': 'False'})
        },
        'chance.eventchoiceoption': {
            'Meta': {'ordering': "('order',)", 'object_name': 'EventChoiceOption'},
            'choice': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'options'", 'to': "orm['chance.EventChoice']"}),
            'display': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'enabled': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'order': ('django.db.models.fields.PositiveIntegerField', [], {'default': '0'})
        },
        'chance.eventchoiceselection': {
            'Meta': {'object_name': 'EventChoiceSelection'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'option': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'+'", 'to': "orm['chance.EventChoiceOption']"}),
            'registration': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'selections'", 'to': "orm['chance.Registration']"})
        },
        'chance.eventfee': {
            'Meta': {'object_name': 'EventFee'},
            'amount': ('django.db.models.fields.DecimalField', [], {'max_digits': '255', 'decimal_places': '2'}),
            'available': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'event': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'fee_options'", 'to': "orm['chance.Event']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        'chance.registration': {
            'Meta': {'object_name': 'Registration'},
            'attendee_email': ('django.db.models.fields.EmailField', [], {'max_length': '75'}),
            'attendee_name': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'null': 'True', 'blank': 'True'}),
            'event': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'registrations'", 'to': "orm['chance.Event']"}),
            'fee_option': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'+'", 'null': 'True', 'to': "orm['chance.EventFee']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'owner': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'+'", 'null': 'True', 'to': "orm['auth.User']"}),
            'paid': ('django.db.models.fields.BooleanField', [], {'default': 'False'})
        },
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        }
    }

    complete_apps = ['chance']


# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding field 'Registration.created'
        db.add_column('chance_registration', 'created',
                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, null=True, blank=True),
                      keep_default=False)

        # Deleting field 'EventChoiceOption.value'
        db.delete_column('chance_eventchoiceoption', 'value')

        # Adding field 'EventChoice.label'
        db.add_column('chance_eventchoice', 'label',
                      self.gf('django.db.models.fields.CharField')(default='label', max_length=255),
                      keep_default=False)


        # Changing field 'EventChoice.name'
        db.alter_column('chance_eventchoice', 'name', self.gf('django.db.models.fields.CharField')(max_length=32))
        # Adding unique constraint on 'EventChoice', fields ['name', 'event']
        db.create_unique('chance_eventchoice', ['name', 'event_id'])


    def backwards(self, orm):
        # Removing unique constraint on 'EventChoice', fields ['name', 'event']
        db.delete_unique('chance_eventchoice', ['name', 'event_id'])

        # Deleting field 'Registration.created'
        db.delete_column('chance_registration', 'created')


        # User chose to not deal with backwards NULL issues for 'EventChoiceOption.value'
        raise RuntimeError("Cannot reverse this migration. 'EventChoiceOption.value' and its values cannot be restored.")
        # Deleting field 'EventChoice.label'
        db.delete_column('chance_eventchoice', 'label')


        # Changing field 'EventChoice.name'
        db.alter_column('chance_eventchoice', 'name', self.gf('django.db.models.fields.CharField')(max_length=255))

    models = {
        'chance.event': {
            'Meta': {'object_name': 'Event'},
            'ends': ('django.db.models.fields.DateTimeField', [], {}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'location': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'registration_limit': ('django.db.models.fields.PositiveSmallIntegerField', [], {'default': '0', 'null': 'True', 'blank': 'True'}),
            'starts': ('django.db.models.fields.DateTimeField', [], {})
        },
        'chance.eventchoice': {
            'Meta': {'ordering': "('order',)", 'unique_together': "(('name', 'event'),)", 'object_name': 'EventChoice'},
            'allow_multiple': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'event': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'choices'", 'to': "orm['chance.Event']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'label': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '32'}),
            'order': ('django.db.models.fields.PositiveIntegerField', [], {'default': '0'}),
            'required': ('django.db.models.fields.BooleanField', [], {'default': 'False'})
        },
        'chance.eventchoiceoption': {
            'Meta': {'ordering': "('order',)", 'object_name': 'EventChoiceOption'},
            'choice': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'options'", 'to': "orm['chance.EventChoice']"}),
            'display': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'enabled': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'order': ('django.db.models.fields.PositiveIntegerField', [], {'default': '0'})
        },
        'chance.eventchoiceselection': {
            'Meta': {'object_name': 'EventChoiceSelection'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'option': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'+'", 'to': "orm['chance.EventChoiceOption']"}),
            'registration': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'selections'", 'to': "orm['chance.Registration']"})
        },
        'chance.eventfee': {
            'Meta': {'object_name': 'EventFee'},
            'amount': ('django.db.models.fields.DecimalField', [], {'max_digits': '255', 'decimal_places': '2'}),
            'available': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'event': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'fee_options'", 'to': "orm['chance.Event']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        'chance.registration': {
            'Meta': {'object_name': 'Registration'},
            'attendee_email': ('django.db.models.fields.EmailField', [], {'max_length': '75'}),
            'attendee_name': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'null': 'True', 'blank': 'True'}),
            'event': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'registrations'", 'to': "orm['chance.Event']"}),
            'fee_option': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'+'", 'null': 'True', 'to': "orm['chance.EventFee']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'paid': ('django.db.models.fields.BooleanField', [], {'default': 'False'})
        }
    }

    complete_apps = ['chance']


from os.path import dirname, join

from setuptools import setup, find_packages



version = '0.3'

setup(
    name = 'django-chance',
    version = version,
    description = "Django CMS Plugin for Google Forms",
    long_description = open(join(dirname(__file__), 'README.rst')).read() + "\n" + 
                       open(join(dirname(__file__), 'HISTORY.rst')).read(),
    classifiers = [
        "Framework :: Django",
        "Development Status :: 3 - Alpha",
        #"Development Status :: 4 - Beta",
        #"Development Status :: 5 - Production/Stable",
        "Programming Language :: Python",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: Apache Software License"],
    keywords = 'django cms plugin events conference',
    author = 'Benjamin Liles',
    author_email = 'benliles@gmail.com',
    url = 'https://github.com/benliles/django-chance',
    packages = find_packages(),
    include_package_data = True,
    zip_safe = False,
    install_requires = [
        'setuptools',
    ],
)



try:
    from reversion import VersionAdmin as ModelAdmin
except ImportError:
    from django.contrib.admin import ModelAdmin

from django.contrib import admin

from chance.models import (Event, EventFee, EventChoice, EventChoiceOption,
        Registration, EventChoiceSelection, Talk, Transaction)



class EventFeeInlineAdmin(admin.TabularInline):
    model = EventFee
    extra = 1

class EventChoiceInlineAdmin(admin.StackedInline):
    model = EventChoice
    extra = 1

class EventAdmin(ModelAdmin):
    date_hierarchy = 'starts'
    inlines = [
        EventFeeInlineAdmin,
        EventChoiceInlineAdmin
    ]

class EventChoiceOptionInlineAdmin(admin.TabularInline):
    model = EventChoiceOption
    extra = 1


class EventChoiceAdmin(ModelAdmin):
    inlines = [
        EventChoiceOptionInlineAdmin
    ]
    exclude = ('event',)

class RegistrationAdmin(ModelAdmin):
    model = Registration
    exclude = ('event',)
    list_filter = ('event', 'paid',)

class TalkAdmin(ModelAdmin):
    list_filter = ('event', 'accepted',)

class TransactionAdmin(ModelAdmin):
    list_display = ('pk', 'owner', 'amount_paid', 'created', 'closed')

admin.site.register(Event, EventAdmin)
admin.site.register(EventChoice, EventChoiceAdmin)
admin.site.register(Registration, RegistrationAdmin)
admin.site.register(Talk, TalkAdmin)
admin.site.register(Transaction, TransactionAdmin)




# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Event'
        db.create_table('chance_event', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('location', self.gf('django.db.models.fields.CharField')(max_length=255, null=True, blank=True)),
            ('starts', self.gf('django.db.models.fields.DateTimeField')()),
            ('ends', self.gf('django.db.models.fields.DateTimeField')()),
            ('registration_limit', self.gf('django.db.models.fields.PositiveSmallIntegerField')(default=0, null=True, blank=True)),
        ))
        db.send_create_signal('chance', ['Event'])

        # Adding model 'EventFee'
        db.create_table('chance_eventfee', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('event', self.gf('django.db.models.fields.related.ForeignKey')(related_name='fee_options', to=orm['chance.Event'])),
            ('available', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('amount', self.gf('django.db.models.fields.DecimalField')(max_digits=255, decimal_places=2)),
        ))
        db.send_create_signal('chance', ['EventFee'])

        # Adding model 'EventChoice'
        db.create_table('chance_eventchoice', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('event', self.gf('django.db.models.fields.related.ForeignKey')(related_name='choices', to=orm['chance.Event'])),
            ('order', self.gf('django.db.models.fields.PositiveIntegerField')(default=0)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('description', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
            ('required', self.gf('django.db.models.fields.BooleanField')(default=False)),
        ))
        db.send_create_signal('chance', ['EventChoice'])

        # Adding model 'EventChoiceOption'
        db.create_table('chance_eventchoiceoption', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('choice', self.gf('django.db.models.fields.related.ForeignKey')(related_name='options', to=orm['chance.EventChoice'])),
            ('order', self.gf('django.db.models.fields.PositiveIntegerField')(default=0)),
            ('value', self.gf('django.db.models.fields.CharField')(max_length=32)),
            ('display', self.gf('django.db.models.fields.CharField')(max_length=128)),
            ('enabled', self.gf('django.db.models.fields.BooleanField')(default=True)),
        ))
        db.send_create_signal('chance', ['EventChoiceOption'])

        # Adding model 'Registration'
        db.create_table('chance_registration', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('event', self.gf('django.db.models.fields.related.ForeignKey')(related_name='registrations', to=orm['chance.Event'])),
            ('attendee_name', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('attendee_email', self.gf('django.db.models.fields.EmailField')(max_length=75)),
            ('fee_option', self.gf('django.db.models.fields.related.ForeignKey')(blank=True, related_name='+', null=True, to=orm['chance.EventFee'])),
            ('paid', self.gf('django.db.models.fields.BooleanField')(default=False)),
        ))
        db.send_create_signal('chance', ['Registration'])

        # Adding model 'EventChoiceSelection'
        db.create_table('chance_eventchoiceselection', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('registration', self.gf('django.db.models.fields.related.ForeignKey')(related_name='selections', to=orm['chance.Registration'])),
            ('option', self.gf('django.db.models.fields.related.ForeignKey')(related_name='+', to=orm['chance.EventChoiceOption'])),
        ))
        db.send_create_signal('chance', ['EventChoiceSelection'])


    def backwards(self, orm):
        # Deleting model 'Event'
        db.delete_table('chance_event')

        # Deleting model 'EventFee'
        db.delete_table('chance_eventfee')

        # Deleting model 'EventChoice'
        db.delete_table('chance_eventchoice')

        # Deleting model 'EventChoiceOption'
        db.delete_table('chance_eventchoiceoption')

        # Deleting model 'Registration'
        db.delete_table('chance_registration')

        # Deleting model 'EventChoiceSelection'
        db.delete_table('chance_eventchoiceselection')


    models = {
        'chance.event': {
            'Meta': {'object_name': 'Event'},
            'ends': ('django.db.models.fields.DateTimeField', [], {}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'location': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'registration_limit': ('django.db.models.fields.PositiveSmallIntegerField', [], {'default': '0', 'null': 'True', 'blank': 'True'}),
            'starts': ('django.db.models.fields.DateTimeField', [], {})
        },
        'chance.eventchoice': {
            'Meta': {'ordering': "('order',)", 'object_name': 'EventChoice'},
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'event': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'choices'", 'to': "orm['chance.Event']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'order': ('django.db.models.fields.PositiveIntegerField', [], {'default': '0'}),
            'required': ('django.db.models.fields.BooleanField', [], {'default': 'False'})
        },
        'chance.eventchoiceoption': {
            'Meta': {'ordering': "('order',)", 'object_name': 'EventChoiceOption'},
            'choice': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'options'", 'to': "orm['chance.EventChoice']"}),
            'display': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'enabled': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'order': ('django.db.models.fields.PositiveIntegerField', [], {'default': '0'}),
            'value': ('django.db.models.fields.CharField', [], {'max_length': '32'})
        },
        'chance.eventchoiceselection': {
            'Meta': {'object_name': 'EventChoiceSelection'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'option': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'+'", 'to': "orm['chance.EventChoiceOption']"}),
            'registration': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'selections'", 'to': "orm['chance.Registration']"})
        },
        'chance.eventfee': {
            'Meta': {'object_name': 'EventFee'},
            'amount': ('django.db.models.fields.DecimalField', [], {'max_digits': '255', 'decimal_places': '2'}),
            'available': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'event': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'fee_options'", 'to': "orm['chance.Event']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        'chance.registration': {
            'Meta': {'object_name': 'Registration'},
            'attendee_email': ('django.db.models.fields.EmailField', [], {'max_length': '75'}),
            'attendee_name': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'event': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'registrations'", 'to': "orm['chance.Event']"}),
            'fee_option': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'+'", 'null': 'True', 'to': "orm['chance.EventFee']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'paid': ('django.db.models.fields.BooleanField', [], {'default': 'False'})
        }
    }

    complete_apps = ['chance']